@@ -121,7 +121,6 @@ import types
 import inspect
 import traceback
 from inspect import isgeneratorfunction, isclass
-from contextlib import contextmanager
 from random import shuffle
 from itertools import dropwhile
 
@@ -130,7 +129,7 @@ from logilab.common import textutils
 from logilab.common import testlib, STD_BLACKLIST
 # use the same unittest module as testlib
 from logilab.common.testlib import unittest, start_interactive_mode
-from logilab.common.deprecation import deprecated
+from logilab.common.testlib import nocoverage, pause_trace, replace_trace  # bwcompat
 from logilab.common.debugger import Debugger, colorize_source
 import doctest
 
@@ -152,62 +151,6 @@ except ImportError:
 
 CONF_FILE = 'pytestconf.py'
 
-## coverage pausing tools
-
-@contextmanager
-def replace_trace(trace=None):
-    """A context manager that temporary replaces the trace function"""
-    oldtrace = sys.gettrace()
-    sys.settrace(trace)
-    try:
-        yield
-    finally:
-        # specific hack to work around a bug in pycoverage, see
-        # https://bitbucket.org/ned/coveragepy/issue/123
-        if (oldtrace is not None and not callable(oldtrace) and
-            hasattr(oldtrace, 'pytrace')):
-            oldtrace = oldtrace.pytrace
-        sys.settrace(oldtrace)
-
-
-def pause_trace():
-    """A context manager that temporary pauses any tracing"""
-    return replace_trace()
-
-class TraceController(object):
-    ctx_stack = []
-
-    @classmethod
-    @deprecated('[lgc 0.63.1] Use the pause_trace() context manager')
-    def pause_tracing(cls):
-        cls.ctx_stack.append(pause_trace())
-        cls.ctx_stack[-1].__enter__()
-
-    @classmethod
-    @deprecated('[lgc 0.63.1] Use the pause_trace() context manager')
-    def resume_tracing(cls):
-        cls.ctx_stack.pop().__exit__(None, None, None)
-
-
-pause_tracing = TraceController.pause_tracing
-resume_tracing = TraceController.resume_tracing
-
-
-def nocoverage(func):
-    """Function decorator that pauses tracing functions"""
-    if hasattr(func, 'uncovered'):
-        return func
-    func.uncovered = True
-
-    def not_covered(*args, **kwargs):
-        with pause_trace():
-            return func(*args, **kwargs)
-    not_covered.uncovered = True
-    return not_covered
-
-## end of coverage pausing tools
-
-
 TESTFILE_RE = re.compile("^((unit)?test.*|smoketest)\.py$")
 def this_is_a_testfile(filename):
     """returns True if `filename` seems to be a test file"""
